==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/LinksResend.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksResendResend;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksResend
 */
@JsonPropertyOrder({ LinksResend.JSON_PROPERTY_RESEND })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksResend implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESEND = "resend";
    private LinksResendResend resend;

    public LinksResend() {
    }

    public LinksResend resend(LinksResendResend resend) {

        this.resend = resend;
        return this;
    }

    /**
     * Get resend
     *
     * @return resend
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RESEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksResendResend getResend() {
        return resend;
    }

    @JsonProperty(JSON_PROPERTY_RESEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setResend(LinksResendResend resend) {
        this.resend = resend;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksResend linksResend = (LinksResend) o;
        return Objects.equals(this.resend, linksResend.resend);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resend);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksResend {\n");
        sb.append("    resend: ").append(toIndentedString(resend)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/LinksResend.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksResendResendInner;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksResend
 */
@JsonPropertyOrder({ LinksResend.JSON_PROPERTY_RESEND })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LinksResend implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESEND = "resend";
    private List<LinksResendResendInner> resend = null;

    public LinksResend() {
    }

    public LinksResend resend(List<LinksResendResendInner> resend) {

        this.resend = resend;
        return this;
    }

    public LinksResend addresendItem(LinksResendResendInner resendItem) {
        if (this.resend == null) {
            this.resend = new ArrayList<>();
        }
        this.resend.add(resendItem);
        return this;
    }

    /**
     * Resends the factor enrollment challenge. See [Resend a Factor
     * enrollment](/openapi/okta-management/management/tag/UserFactor/#tag/UserFactor/operation/resendEnrollFactor).
     *
     * @return resend
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Resends the factor enrollment challenge. See [Resend a Factor enrollment](/openapi/okta-management/management/tag/UserFactor/#tag/UserFactor/operation/resendEnrollFactor).")
    @JsonProperty(JSON_PROPERTY_RESEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<LinksResendResendInner> getResend() {
        return resend;
    }

    @JsonProperty(JSON_PROPERTY_RESEND)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setResend(List<LinksResendResendInner> resend) {
        this.resend = resend;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksResend linksResend = (LinksResend) o;
        return Objects.equals(this.resend, linksResend.resend);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resend);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksResend {\n");
        sb.append("    resend: ").append(toIndentedString(resend)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
